@@ -371,12 +371,12 @@ class PaLM(nn.Module):
 
             cross_attn = None
             if cross_attend:
-                cross_attn = CrossAttention(
+                cross_attn = Residual(CrossAttention(
                     dim = dim,
                     dim_head = dim_head,
                     heads = heads,
                     dropout = attn_dropout
-                )
+                ))
 
             self.layers.append(nn.ModuleList([
                 cross_attn,
