@@ -20,7 +20,7 @@ from torch.nn.utils.rnn import pad_sequence
 from einops import rearrange, repeat
 from einops.layers.torch import Rearrange
 
-from palm_rlhf_pytorch.palm_rlhf_pytorch import PaLM
+from palm_rlhf_pytorch.palm import PaLM
 from palm_rlhf_pytorch.reward import RewardModel
 from palm_rlhf_pytorch.optimizer import get_optimizer
 from palm_rlhf_pytorch.utils import masked_mean, eval_decorator
